<?php
/**
 * WP_Rig\WP_Rig\Accessibility\Component class
 *
 * @package xanatek
 */

namespace WP_Rig\WP_Rig\Accessibility;

use WP_Rig\WP_Rig\Component_Interface;
use function WP_Rig\WP_Rig\xanatek;
use WP_Post;
use function add_action;
use function add_filter;
use function wp_enqueue_script;
use function get_theme_file_uri;
use function get_theme_file_path;
use function wp_script_add_data;
use function wp_localize_script;

/**
 * Class for improving accessibility among various core features.
 */
class Component implements Component_Interface {

	/**
	 * Gets the unique identifier for the theme component.
	 *
	 * @return string Component slug.
	 */
	public function get_slug() : string {
		return 'accessibility';
	}

	/**
	 * Adds the action and filter hooks to integrate with WordPress.
	 */
	public function initialize() {
		add_action( 'wp_enqueue_scripts', [ $this, 'action_enqueue_navigation_script' ] );
		add_action( 'wp_enqueue_scripts', [ $this, 'action_enqueue_smoothscroll_script' ] );
		add_action( 'wp_enqueue_scripts', [ $this, 'action_enqueue_connect_script' ] );
		add_action( 'wp_print_footer_scripts', [ $this, 'action_print_skip_link_focus_fix' ] );
		add_filter( 'nav_menu_link_attributes', [ $this, 'filter_nav_menu_link_attributes_aria_current' ], 10, 2 );
		add_filter( 'page_menu_link_attributes', [ $this, 'filter_nav_menu_link_attributes_aria_current' ], 10, 2 );
	}

	/**
	 * Enqueues a script that improves navigation menu accessibility.
	 */
	public function action_enqueue_navigation_script() {

		// If the AMP plugin is active, return early.
		if ( xanatek()->is_amp() ) {
			return;
		}

		// Enqueue the navigation script.
		wp_enqueue_script(
			'xanatek-navigation',
			get_theme_file_uri( '/assets/js/navigation.min.js' ),
			[],
			xanatek()->get_asset_version( get_theme_file_path( '/assets/js/navigation.min.js' ) ),
			false
		);
		wp_script_add_data( 'xanatek-navigation', 'defer', true );
		wp_script_add_data( 'xanatek-navigation', 'precache', true );
		wp_localize_script(
			'xanatek-navigation',
			'xanatekScreenReaderText',
			[
				'expand'   => __( 'Expand child menu', 'xanatek' ),
				'collapse' => __( 'Collapse child menu', 'xanatek' ),
			]
		);
	}

	/**
	 * Enqueues a script that implements smooth scrolling.
	 */
	public function action_enqueue_smoothscroll_script() {

		// If the AMP plugin is active, return early.
		if ( xanatek()->is_amp() ) {
			return;
		}

			// Enqueue the navigation script.
		wp_enqueue_script(
			'xanatek-smoothscroll',
			get_theme_file_uri( '/assets/js/smoothscroll.min.js' ),
			[],
			xanatek()->get_asset_version( get_theme_file_path( '/assets/js/smoothscroll.min.js' ) ),
			false
		);
		wp_script_add_data( 'xanatek-smoothscroll', 'defer', true );
		wp_script_add_data( 'xanatek-smoothscroll', 'precache', true );
	}

	/**
	 * Enqueues a script that controls the Connect hover functions.
	 */
	public function action_enqueue_connect_script() {

		// If the AMP plugin is active, return early.
		if ( xanatek()->is_amp() ) {
			return;
		}

		// Enqueue the jQuery script.
		wp_enqueue_script(
			'xanatek-jquery',
			'https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js',
			[],
			xanatek()->get_asset_version( 'https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js' ),
			false
		);
		wp_script_add_data( 'xanatek-jquery', 'async', true );
		wp_script_add_data( 'xanatek-jquery', 'precache', true );

		// Enqueue the Connect script.
		wp_enqueue_script(
			'xanatek-connect',
			get_theme_file_uri( '/assets/js/connect.min.js' ),
			[],
			xanatek()->get_asset_version( get_theme_file_path( '/assets/js/connect.min.js' ) ),
			false
		);
		wp_script_add_data( 'xanatek-connect', 'defer', true );
		wp_script_add_data( 'xanatek-connect', 'precache', true );
	}

	/**
	 * Prints an inline script to fix skip link focus in IE11.
	 *
	 * The script is not enqueued because it is tiny and because it is only for IE11,
	 * thus it does not warrant having an entire dedicated blocking script being loaded.
	 *
	 * Since it will never need to be changed, it is simply printed in its minified version.
	 *
	 * @link https://git.io/vWdr2
	 */
	public function action_print_skip_link_focus_fix() {

		// If the AMP plugin is active, return early.
		if ( xanatek()->is_amp() ) {
			return;
		}

		// Print the minified script.
		?>
		<script>
		/(trident|msie)/i.test(navigator.userAgent)&&document.getElementById&&window.addEventListener&&window.addEventListener("hashchange",function(){var t,e=location.hash.substring(1);/^[A-z0-9_-]+$/.test(e)&&(t=document.getElementById(e))&&(/^(?:a|select|input|button|textarea)$/i.test(t.tagName)||(t.tabIndex=-1),t.focus())},!1);
		</script>
		<?php
	}

	/**
	 * Filters the HTML attributes applied to a menu item's anchor element.
	 *
	 * Checks if the menu item is the current menu item and adds the aria "current" attribute.
	 *
	 * @param array   $atts The HTML attributes applied to the menu item's `<a>` element.
	 * @param WP_Post $item The current menu item.
	 * @return array Modified HTML attributes
	 */
	public function filter_nav_menu_link_attributes_aria_current( array $atts, WP_Post $item ) : array {
		if ( isset( $item->current ) ) {
			if ( $item->current ) {
				$atts['aria-current'] = 'page';
			}
		} elseif ( ! empty( $item->ID ) ) {
			global $post;

			if ( ! empty( $post->ID ) && (int) $post->ID === (int) $item->ID ) {
				$atts['aria-current'] = 'page';
			}
		}

		return $atts;
	}
}
