<?php
/**
 * WP_Rig\WP_Rig\Editor\Component class
 *
 * @package xanatek
 */

namespace WP_Rig\WP_Rig\Editor;

use WP_Rig\WP_Rig\Component_Interface;
use function add_action;
use function add_theme_support;

/**
 * Class for integrating with the block editor.
 *
 * @link https://wordpress.org/gutenberg/handbook/extensibility/theme-support/
 */
class Component implements Component_Interface {

	/**
	 * Gets the unique identifier for the theme component.
	 *
	 * @return string Component slug.
	 */
	public function get_slug() : string {
		return 'editor';
	}

	/**
	 * Adds the action and filter hooks to integrate with WordPress.
	 */
	public function initialize() {
		add_action( 'after_setup_theme', [ $this, 'action_add_editor_support' ] );
	}

	/**
	 * Adds support for various editor features.
	 */
	public function action_add_editor_support() {
		// Add support for editor styles.
		add_theme_support( 'editor-styles' );

		// Add support for default block styles.
		add_theme_support( 'wp-block-styles' );

		// Add support for wide-aligned images.
		add_theme_support( 'align-wide' );

		/**
		 * Add support for color palettes.
		 *
		 * To preserve color behavior across themes, use these naming conventions:
		 * - Use primary and secondary color for main variations.
		 * - Use `theme-[color-name]` naming standard for standard colors (red, blue, etc).
		 * - Use `custom-[color-name]` for non-standard colors.
		 *
		 * Add the line below to disable the custom color picker in the editor.
		 * add_theme_support( 'disable-custom-colors' );
		 */
		add_theme_support(
			'editor-color-palette',
			[
				[
					'name'  => __( 'Primary', 'xanatek' ),
					'slug'  => 'theme-primary',
					'color' => '#1995d3',
				],
				[
					'name'  => __( 'Secondary', 'xanatek' ),
					'slug'  => 'theme-secondary',
					'color' => '#3f3e29',
				],
				[
					'name'  => __( 'Red', 'xanatek' ),
					'slug'  => 'theme-red',
					'color' => '#c0392b',
				],
				[
					'name'  => __( 'Green', 'xanatek' ),
					'slug'  => 'theme-green',
					'color' => '#27ae60',
				],
				[
					'name'  => __( 'Blue', 'xanatek' ),
					'slug'  => 'theme-blue',
					'color' => '#1995d3',
				],
				[
					'name'  => __( 'Transparent Blue', 'xanatek' ),
					'slug'  => 'theme-blue-trans',
					'color' => 'rgba(25, 148, 210, 0.1)',
				],
				[
					'name'  => __( 'Dark Blue', 'xanatek' ),
					'slug'  => 'theme-dark-blue',
					'color' => '#1779ba',
				],
				[
					'name'  => __( 'Yellow', 'xanatek' ),
					'slug'  => 'theme-yellow',
					'color' => '#f1c40f',
				],
				[
					'name'  => __( 'Black', 'xanatek' ),
					'slug'  => 'theme-black',
					'color' => '#3f3e29',
				],
				[
					'name'  => __( 'Transparent Black', 'xanatek' ),
					'slug'  => 'theme-black-trans',
					'color' => 'rgba(0,0,0,0.4)',
				],
				[
					'name'  => __( 'Grey', 'xanatek' ),
					'slug'  => 'theme-grey',
					'color' => '#8c8c8c',
				],
				[
					'name'	=>__( 'Transparent Grey', 'xanatek' ),
					'slug'	=> 'theme-grey-trans',
					'color'	=> 'rgb(218, 218, 218, 0.1)',
				],
				[
					'name'  => __( 'White', 'xanatek' ),
					'slug'  => 'theme-white',
					'color' => '#fefefe',
				],
				[
					'name'  => __( 'Dusty daylight', 'xanatek' ),
					'slug'  => 'custom-daylight',
					'color' => '#97c0b7',
				],
				[
					'name'  => __( 'Dusty sun', 'xanatek' ),
					'slug'  => 'custom-sun',
					'color' => '#eee9d1',
				],
			]
		);

		/*
		 * Add support custom font sizes.
		 *
		 * Add the line below to disable the custom color picker in the editor.
		 * add_theme_support( 'disable-custom-font-sizes' );
		 */
		add_theme_support(
			'editor-font-sizes',
			[
				[
					'name'      => __( 'Small', 'xanatek' ),
					'shortName' => __( 'S', 'xanatek' ),
					'size'      => 16,
					'slug'      => 'small',
				],
				[
					'name'      => __( 'Medium', 'xanatek' ),
					'shortName' => __( 'M', 'xanatek' ),
					'size'      => 25,
					'slug'      => 'medium',
				],
				[
					'name'      => __( 'Large', 'xanatek' ),
					'shortName' => __( 'L', 'xanatek' ),
					'size'      => 31,
					'slug'      => 'large',
				],
				[
					'name'      => __( 'Larger', 'xanatek' ),
					'shortName' => __( 'XL', 'xanatek' ),
					'size'      => 39,
					'slug'      => 'larger',
				],
			]
		);
	}
}
